OC.L10N.register(
    "files",
    {
    "Unknown error" : "غیر معروف خرابی",
    "Delete" : "حذف کریں",
    "Unshare" : "شئیرنگ ختم کریں",
    "Download" : "ڈاؤن لوڈ،",
    "Error" : "ایرر",
    "Name" : "اسم",
    "Save" : "حفظ",
    "Settings" : "ترتیبات"
},
"nplurals=2; plural=(n != 1);");
